=======
History
=======

0.2.0 (2021-08-15)
------------------

* Replaces setuptools with filt
* Updates linting
* Replaces TravisCI with Github Actions
* Replaces requests with httpx
* Replaces click with typer
* Adds Pydantic `PlayerState`, `Song` and `Episode` models
* Updates for `sxm==0.2.5` client

0.1.0 (2018-12-25)
------------------

* First release on PyPI.
